==> free-sa-1.2.1.tar.gz: free-sa-1.2.1/src/reports/r_index.c <==
#include "global.h"


/* UNOPTIMIZED */
void ReportIndex() {
    DIR *TargetDir;
    FILE *IR;
    struct dirent *tDirEnt;
    struct stat tStat;
    char *tBuf, *tDescription[5], *t, *ot, *sReportDir = NULL, tfname[MAXFILENAME];
    short int i, deCount;
    char stext[128];
    
    /* IR: open target dir */
    if (!(TargetDir = opendir(cfg.TargetDir))) SAexit(F_REPORTINDEX, "Can't open dir %s. %s", cfg.TargetDir, strerror(errno));
    deCount = SAgetdirecount(TargetDir);

    /* Prepare for overwrite option */
    if (cfg.Overwrite) if ((sReportDir = strrchr(icfg.ReportDir, (int)'/') + 1L) == NULL) SAexit(F_REPORTINDEX, "Can't detect last directory for %s", icfg.ReportDir);
    
    /* Open global index file */
    sprintf(stext, "%s (%s)", loc->GenerationD, loc->Desc);
    IR = SAfopenH("./", 'r', loc->PSP, stext, 0, "w", TEMPL_REPORT, cfg.TargetDir, icfg.IRname);
    fprintf(IR, "<tr><th>%s<th>%s<th>%s<th>%s<th>%s\n", loc->Period, loc->GenerationD, loc->Users, loc->Bytes, loc->Configuration);
    
    /* Check every directory entry if it is report directory */
    while ((tDirEnt = SAreaddir(TargetDir, deCount--))) {
	if (tDirEnt->d_name[10] == '-' && tDirEnt->d_name[21] == '-') {
	    /* Read description file to memory, if some is damaged then skip them */
	    if ((tBuf = (char *)SAfreadMC(&tStat, "%s/%s/%s", cfg.TargetDir, tDirEnt->d_name, icfg.DFname)) == NULL) continue;

	    /* Fill description array fields with values */	    
	    ot = tBuf;
	    for (i = 0; i < 4 && (t = strchr(ot, '\n')) != NULL; i++) {
	        tDescription[i] = ot;
	        t[0] = '\0';
	        ot = t + 1L;
	    }
	    
	    /* Delete all period duplicated reports (prevoiusly created) */
	    if (cfg.Overwrite) 
		if (strcmp(sReportDir, tDirEnt->d_name) && !strcmp(icfg.Period, tDescription[0])) {
		    free(tBuf);
		    snprintf(tfname, MAXFILENAME, "%s/%s", cfg.TargetDir, tDirEnt->d_name);
		    SAsystem(CMDRM, CMDRM, "-rf", tfname, NULL);
		    continue;
		}
	    
	    /* IR: write */
	    fprintf(IR, "<tr><td><a href=\"%s/%s.html\">%s</a><td>%s<td>%s<td>%s<td class=lt>%s\n", 
tDirEnt->d_name, icfg.LRname, tDescription[0], GetDT(tStat.st_mtime, "%x %X"), tDescription[3], tDescription[2], tDescription[1]);
	    	    
	    free(tBuf);
	}
    }
    
    /* IR: close */
    SAfcloseH(IR, "index.html");
}

==> free-sa-1.2.4.tar.gz: free-sa-1.2.4/src/reports/r_index.c <==
#include "global.h"


/* UNOPTIMIZED */
void ReportIndex() {
    DIR *TargetDir;
    FILE *IR;
    struct dirent *tDirEnt;
    struct stat tStat;
    char *tBuf, *tDescription[5], *t, *ot, *sReportDir = NULL, tfname[MAXFILENAME];
    short int i, deCount;
    char stext[128];
    
    /* IR: open target dir */
    if (!(TargetDir = opendir(cfg.TargetDir))) SAexit(F_REPORTINDEX, "Can't open dir %s. %s", cfg.TargetDir, strerror(errno));
    deCount = SAgetdirecount(TargetDir);

    /* Prepare for overwrite option */
    if (cfg.Overwrite) if ((sReportDir = strrchr(icfg.ReportDir, (int)'/') + 1L) == NULL) SAexit(F_REPORTINDEX, "Can't detect last directory for %s", icfg.ReportDir);
    
    /* Open global index file */
    snprintf(stext, sizeof(stext), "%s (%s)", loc->GenerationD, loc->Desc);
    IR = SAfopenH("./", 'r', loc->PSP, stext, 0, "w", TEMPL_REPORT, cfg.TargetDir, icfg.IRname);
    fprintf(IR, "<tr><th>%s<th>%s<th>%s<th>%s<th>%s\n", loc->Period, loc->GenerationD, loc->Users, loc->Bytes, loc->Configuration);
    
    /* Check every directory entry if it is report directory */
    while ((tDirEnt = SAreaddir(TargetDir, deCount--)) != NULL) {
	if (tDirEnt->d_name[10] == '-' && tDirEnt->d_name[21] == '-') {
	    /* Read description file to memory, if some is damaged then skip them */
	    if ((tBuf = (char *)SAfreadMC(&tStat, "%s/%s/%s", cfg.TargetDir, tDirEnt->d_name, icfg.DFname)) == NULL) continue;

	    /* Fill description array fields with values */	    
	    ot = tBuf;
	    for (i = 0; i < 4 && (t = strchr(ot, '\n')) != NULL; i++) {
	        tDescription[i] = ot;
	        t[0] = '\0';
	        ot = t + 1L;
	    }
	    
	    /* Delete all period duplicated reports (prevoiusly created) */
	    if (cfg.Overwrite) 
		if (strcmp(sReportDir, tDirEnt->d_name) && !strcmp(icfg.Period, tDescription[0])) {
		    free(tBuf);
		    snprintf(tfname, MAXFILENAME, "%s/%s", cfg.TargetDir, tDirEnt->d_name);
		    SAsystem(CMDRM, CMDRM, "-rf", tfname, NULL);
		    continue;
		}
	    
	    /* IR: write */
	    fprintf(IR, "<tr><td><a href=\"%s/%s.html\">%s</a><td>%s<td>%s<td>%s<td class=lt>%s\n", 
tDirEnt->d_name, icfg.LRname, tDescription[0], GetDT(tStat.st_mtime, "%x %X"), tDescription[3], tDescription[2], tDescription[1]);
	    	    
	    free(tBuf);
	}
    }
    
    /* IR: close */
    SAfcloseH(IR, "index.html");
}
